﻿using System;
using System.IO;
using OutlookMessageLibrary;
using System.Reflection;

namespace OutlookMessageReading
{
    class Program
    {
        static void Main(string[] args)
        {
            const string msgFile = "Example.msg"; 

            try
            {
                var reader = new OutlookMessageReader();

                Console.WriteLine("Content of '{0}':", msgFile);
                Console.WriteLine("------------------ BEGIN MESSAGE --------------------");

                //Load message body, attachment list and other message specific properties
                OutlookMessage message = reader.Load(@"Example.msg");

                Console.WriteLine("From: {0}", message.From);
                Console.WriteLine("To: {0}", message.To);
                Console.WriteLine("Subject: {0}", message.Subject);
                Console.WriteLine("Attachments: {0}", string.Join(",", message.Attachments));
                Console.WriteLine();
                Console.WriteLine("Body: {0}", message.Body);
                Console.WriteLine("------------------ END MESSAGE --------------------");
                Console.WriteLine();
                var outputDir = Path.Combine(GetCurrentDirectory(), "Output");
                if(!Directory.Exists(outputDir))
                {
                    Directory.CreateDirectory(outputDir);

                }
                Console.WriteLine("Extracting data of '{0}' to '{1}'...", msgFile, outputDir);

                //Extracts message body and attachments from specified file to output folder
                reader.ExtractData(msgFile, outputDir, false);
                Console.WriteLine("Finished!");

                Console.WriteLine();

            }
            catch(Exception ex)
            {
                Console.WriteLine(ex.Message);
            }
            Console.WriteLine("Press Enter to close the program.");
            Console.ReadLine();
        }

        private static string GetCurrentDirectory()
        {
            return Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location);
        }
    }
}
